@@ -4,6 +4,7 @@ use crate::app::{
 use crate::path;
 use anyhow::{Error, Result};
 use path_absolutize::Absolutize;
+use rayon::prelude::*;
 use std::fs;
 use std::path::PathBuf;
 use std::sync::mpsc::Sender;
@@ -12,12 +13,12 @@ use std::thread;
 pub fn explore(parent: &PathBuf, config: &ExplorerConfig) -> Result<Vec<Node>> {
     let dirs = fs::read_dir(parent)?;
     let nodes = dirs
+        .par_bridge()
         .filter_map(|d| {
-            d.ok().map(|e| {
+            d.ok().and_then(|e| {
                 e.path()
                     .file_name()
                     .map(|n| n.to_string_lossy().to_string())
-                    .unwrap_or_default()
             })
         })
         .map(|name| Node::new(parent.to_string_lossy().to_string(), name))
@@ -36,7 +37,7 @@ pub fn explore(parent: &PathBuf, config: &ExplorerConfig) -> Result<Vec<Node>> {
         .unwrap_or(false);
 
     if !is_ordered_search {
-        nodes.sort_by(|a, b| config.sort(a, b));
+        nodes.par_sort_unstable_by(|a, b| config.sort(a, b));
     }
 
     Ok(nodes)
@@ -146,7 +147,7 @@ pub(crate) fn try_complete_path(
 
     let direntries = fs::read_dir(&parent)?
         .filter_map(|d| d.ok())
-        .map(|e| (e.file_name().to_string_lossy().to_string()));
+        .map(|e| e.file_name().to_string_lossy().to_string());
 
     let mut matches = direntries
         .filter(|n| n.starts_with(&fname))
