@@ -1,6 +1,6 @@
-use crossterm::event::{KeyCode, KeyEvent, KeyModifiers};
 use serde::{Deserialize, Serialize};
 use std::cmp::Ordering;
+use tui::crossterm::event::{KeyCode, KeyEvent, KeyModifiers};
 use tui_input::InputRequest;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Serialize, Deserialize)]
@@ -731,12 +731,6 @@ impl From<char> for Key {
     }
 }
 
-impl From<String> for Key {
-    fn from(string: String) -> Self {
-        string.into()
-    }
-}
-
 impl From<&str> for Key {
     fn from(string: &str) -> Self {
         if string.len() == 1 {
