@@ -12,9 +12,6 @@ use crate::ui::NO_COLOR;
 use crate::ui::UI;
 use crate::yaml;
 use anyhow::{bail, Error, Result};
-use crossterm::event;
-use crossterm::execute;
-use crossterm::terminal as term;
 use mlua::LuaSerdeExt;
 use mlua::Value;
 use std::fs;
@@ -24,6 +21,9 @@ use std::path::PathBuf;
 use std::process::{Command, Stdio};
 use std::sync::mpsc;
 use tui::backend::CrosstermBackend;
+use tui::crossterm::event;
+use tui::crossterm::execute;
+use tui::crossterm::terminal as term;
 use tui::Terminal;
 use tui_input::Input;
 
